Documentation
¶
Index ¶
- Variables
- func Clear(obj Object)
- func EqSet(a, b Set) bool
- func EqSlice(a, b Slice) bool
- func First(ss ...string) string
- func HasBlank(ss ...string) bool
- func In(s string, ss []string) bool
- func InBitField(s string, m *CharBitField) bool
- func InRange(s string, m *CharMap) bool
- func Last(ss ...string) string
- func Purge(m Set)
- func Remove(m Set, ss Slice)
- func Zero(m Set)
- type CharBitField
- type CharMap
- type MultiObject
- type Object
- type Set
- type Slice
Constants ¶
This section is empty.
Variables ¶
var Sort = sort.Strings
Sort is a convenience alias so you don't have to import package sort.
Functions ¶
func InBitField ¶
func InBitField(s string, m *CharBitField) bool
Types ¶
type CharBitField ¶
type CharBitField = [256 / 8]byte
CharBitField is a bit field for testing character ranges. It is not as fast as CharMap, but it is 8 times smaller if that's important for some reason.
func MakeCharBitField ¶
func MakeCharBitField(s string) *CharBitField
type CharMap ¶
type CharMap = [256]bool
CharMap is an array for use in mapping from byte to bool and testing whether the characters of string are in range.
func MakeCharMap ¶
type MultiObject ¶
func Merge ¶
func Merge(dst, a, b MultiObject) MultiObject
func ToMultiObject ¶
func ToMultiObject(obj Object) MultiObject
type Set ¶
func SymDiffSets ¶
Click to show internal directories.
Click to hide internal directories.